cloud

package
v1.8.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 10, 2020 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Overview

Package cloud implements common google cloud utilities.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ProjectID

func ProjectID() string

ProjectID returns the current Google Cloud project ID.

Types

This section is empty.

Directories

Path Synopsis
db
Package db implements various helpers for accessing Cloud Datastore.
Package db implements various helpers for accessing Cloud Datastore.
types
Package types contains Datastore types (auto-generated from src/python/datastore/data_types.py).
Package types contains Datastore types (auto-generated from src/python/datastore/data_types.py).
Package gcs implements a buckets.Provider for Google Cloud Storage.
Package gcs implements a buckets.Provider for Google Cloud Storage.
Package stackdriver implements logging using Stackdriver.
Package stackdriver implements logging using Stackdriver.

Jump to