package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Feb 7, 2019
License: Apache-2.0
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package stackdriver implements logging using Stackdriver.
Logger is an implementation of a logs.Logger that sends logs to StackDriver.
Errorf logs an error entry.
Panicf logs an error entry and panics.
Warnf logs an warning entry.
type Payload struct {
Message string `json:"message"`
BotName string `json:"bot_name"`
TaskPayload string `json:"task_payload"`
}
Payload represents the log payload that we send.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.